@@ -43,6 +43,8 @@ requires PTY.")
 
 (if (featurep 'mule) (setq mew-mule-p t))
 
+(require 'easymenu) ;; to prepend the loading messages
+(require 'pp) ;; to prevent the loading messages
 (cond
  ((featurep 'xemacs)
   (setq mew-temacs-p nil)
@@ -65,6 +67,9 @@ requires PTY.")
       (require 'mew-temacs)
     (if (eq window-system 'x) (setq mew-icon-p t))
     (setq mew-gemacs-p t)
+    (require 'image) ;; to prepend the loading messages
+    (require 'jit-lock) ;; to prepend the loading messages
+    (require 'regexp-opt) ;; to prepend the loading messages
     (require 'mew-gemacs))
   (setq mew-mule-ver 3)
   (require 'mew-mule3)))
@@ -94,13 +99,15 @@ requires PTY.")
   ;;
   (defsubst mew-mark () (marker-position (mark-marker)))
   ;;
-  (require 'mew-md5)))
+  (if (string< emacs-version "21")
+      (require 'mew-md5)
+    (defun mew-md5 (str)
+      (md5 str nil nil 'binary)))))
 
 ;;;
 ;;; Misc
 ;;;
 
-;; xxx
 (defun mew-timer (sec func) (run-at-time sec sec func))
 
 (if (fboundp 'characterp)
@@ -169,7 +176,7 @@ requires PTY.")
 
 (defsubst mew-overlay-delete-region (beg end)
   (interactive "r")
-  (mapcar (function mew-overlay-delete) (overlays-in beg end))
+  (mapcar 'mew-overlay-delete (overlays-in beg end))
   (if (fboundp 'remove-images) (remove-images beg end))) ;; xxx
 
 (defsubst mew-overlay-delete-buffer ()
@@ -181,24 +188,36 @@ requires PTY.")
 ;;; File operations
 ;;;
 
+(if (or mew-xemacs-p mew-gemacs-p)
+    (defalias 'mew-face-spec-set 'face-spec-set)
+  ;; face-spec-set on Emacs 20.7 does not effect new frames.
+  (defun mew-face-spec-set (face spec)
+    "Set FACE's attributes according to the first matching entry in SPEC
+on all frames."
+    (custom-set-faces `(,face ,spec))))
+
+;;;
+;;; File operations
+;;;
+
 (cond
  ((fboundp 'make-symbolic-link)
   (defsubst mew-symbolic-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p (file-chase-links filename))
-	(error "Can't make a symbolic link to directory")
+	(error "Cannot make a symbolic link to directory")
       (make-symbolic-link filename newname OK-IF-ALREADY-EXISTS)))
   (defsubst mew-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p (file-chase-links filename))
-	(error "Can't make a link to directory")
+	(error "Cannot make a link to directory")
       (add-name-to-file filename newname OK-IF-ALREADY-EXISTS))))
  (t
   (defsubst mew-symbolic-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p filename)
-	(error "Can't make a copy of directory")
+	(error "Cannot make a copy of directory")
       (copy-file filename newname OK-IF-ALREADY-EXISTS 'keepdate)))
   (defsubst mew-link (filename newname &optional OK-IF-ALREADY-EXISTS)
     (if (file-directory-p filename)
-	(error "Can't make a copy of directory")
+	(error "Cannot make a copy of directory")
       (copy-file filename newname OK-IF-ALREADY-EXISTS 'keepdate)))))
 
 ;;;
@@ -272,7 +291,7 @@ requires PTY.")
 	    (not (zerop (logand len 3)))
 	    (< padlen 0)
 	    (> padlen 2))
-	nil);; return value
+	nil) ;; return value
        ((zerop (setq len (- len padlen))) "")
        (t
 	(setq ret (make-string (/ (* len 3) 4) ?a))
